summaryrefslogtreecommitdiffstats
path: root/kalzium/src/periodictableview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commiteb570158698cf61dad4f77d950ef908160f6c3cc (patch)
tree649bf182bcf0a20bed5035d25ffd77de5aee138a /kalzium/src/periodictableview.h
parentd8762de95349dc6edaa34db9bf699b367c1af6b1 (diff)
downloadtdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.tar.gz
tdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalzium/src/periodictableview.h')
-rw-r--r--kalzium/src/periodictableview.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kalzium/src/periodictableview.h b/kalzium/src/periodictableview.h
index 8115ebe2..196f8290 100644
--- a/kalzium/src/periodictableview.h
+++ b/kalzium/src/periodictableview.h
@@ -46,10 +46,10 @@ class PerodicTableView : public TQWidget
public:
/**
* Constructor
* @param tqparent tqparent widget
* @param name name of this widget
*/
- PerodicTableView( TQWidget *tqparent = 0, const char *name = 0);
+ PerodicTableView( TQWidget *parent = 0, const char *name = 0);
~PerodicTableView();
enum SCHEMETYPE
@@ -46,10 +46,10 @@ class PerodicTableView : public TQWidget
/**
* Constructor
- * @param tqparent tqparent widget
+ * @param parent parent widget
* @param name name of this widget
*/